@@ -39,7 +39,6 @@ def graph_plotter(plot_information, values_list, x_limits=("x_min", "x_max"),
 
     title_text allows the user to give figures custom titles in the form of a string.
     """
-    # TODO: KEEP AN EYE ON THESE:
     title = None
     x = []
     y = []
@@ -254,15 +253,22 @@ def graph_plotter(plot_information, values_list, x_limits=("x_min", "x_max"),
             # Assigns data to variables
             lat = y[data_set][2]
             long = x[data_set][2]
+            z_var = plot_data_map[data_set][0][0][0]
+            z_var_data = plot_data_map[data_set][0][0][2]
+            z_var_gps_time_data = plot_data_map[data_set][2][0][2]
+            z_var_unit = plot_data_map[data_set][0][0][1]
+            z_var_time_data = plot_data_map[data_set][1][0][2]
             if generate_title is True:
                 title_text = "Latitude v Longitude for " + str(flight_dates_list[data_set])
             # Plots map with data
-            backplt_map(lat, long, z_var=plot_data_map[data_set], text_title=title_text,
+            backplt_map(lat, long, z_var=z_var, z_var_unit=z_var_unit, z_var_data=z_var_data,
+                        z_var_time_data=z_var_time_data, z_var_gps_time_data=z_var_gps_time_data, text_title=title_text,
                         z_var_limits=map_info_limits)
             # Plots a second map only if one flight is being analysed
             if single_flight is True:
-                backplt_map(lat, long, z_var=plot_data_map[data_set], scale_factor=float(1 / scale),
-                            text_title=title_text, z_var_limits=map_info_limits)
+                backplt_map(lat, long, z_var=z_var, z_var_unit=z_var_unit, z_var_data=z_var_data,
+                            z_var_time_data=z_var_time_data, z_var_gps_time_data=z_var_gps_time_data,
+                            scale_factor=float(1 / scale), text_title=title_text, z_var_limits=map_info_limits)
         return
 
     elif plot_info == 1 and x[0][0] == 'Longitude' and y[0][0] == 'Latitude' and map_modules_imported is False:
@@ -424,7 +430,6 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
     title_text allows the user to give figures custom titles in the form of a string.
     """
 
-    # TODO: KEEP AN EYE ON THESE:
     text = None
     title = None
     reference_y_unit = None
@@ -882,11 +887,27 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
     plt.show()
 
 
-def backplt_map(lat, long, z_var, scale_factor=1, text_title=None, z_var_limits=(None, None)):
+def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_time_data=None, z_var_gps_time_data=None,
+                scale_factor=1, text_title=None, z_var_limits=(None, None)):
     """
+    Currently this is a support function to graph_plotter() and should not be used on its own.
     This plots a map behind some latitude-longitude data and colours the line according to a third variable (z_var).
 
+    z_var = String for the name of the variable e.g. "Altitude"
+    z_var_unit = String for the units of the variable e.g. "m"
+    z_var_data = List of the data to be plotted e.g. [5, 12, 14]
+    z_var_time_data = List of the time data accompanying z_var_data in seconds e.g. [1, 2, 3]
+    z_var_gps_time_data = List of time data from the gps data set in seconds. This should
+        have the same length as the latitude/longtude data. e.g. [1, 1.5, 2, 2.5, 3]
     """
+    # Checks that the correct modules have been imported:
+    try:
+        import geopandas as gpd
+        import contextily as ctx
+        from pyproj import Proj as proj, transform
+    except ImportError:
+        raise ImportError("Make sure that geopandas, contextily and pyproj are installed before continuing.")
+
     # Sets titles for the data frame
     column_titles = np.array(['index', 'lat, long'])
     index = range(len(lat))
@@ -934,53 +955,70 @@ def backplt_map(lat, long, z_var, scale_factor=1, text_title=None, z_var_limits=
                      path_data_geo['geometry'].y]
 
     # Processes data for the colour scale:
-    # Interpolates the data for the colour series over the data's time scale
-    # z_var[1][0][2] = colour variable time data
-    # z_var[0][0][2] = colour variable data
-    z_var_interp = interp.interp1d(z_var[1][0][2], z_var[0][0][2])
-
-    # Creates the data series of same length as the latitude/longitude data:
-    # z_var[2][0][2] = gps time data
-    colour_data_uncut = []
-    for point in [p for p in z_var[2][0][2] if min(z_var[1][0][2]) <= p <= max(z_var[1][0][2])]:
-        colour_data_uncut.append(z_var_interp(point))
-
-    # TODO: THIS NEEDS FIXING IN A WAY THAT WORKS BETTER. NEED TO MATCH THE TIME STAMPS OF THE LOCATION DATA WITH
-    #  THE COLOUR DATA.
-    # Makes sure that the colour data has the same length as the latitude and longitude data
-    colour_data = []
-    if len(geometry_data[0]) != len(colour_data_uncut):
-        for point in colour_data_uncut[:(len(geometry_data) - 1)]:
-            colour_data.append(point)
+    # Checks that all the necessary data has been entered correctly.
+    z_var_complete = [z_var, z_var_data, z_var_gps_time_data, z_var_unit, z_var_time_data]
+    if all in z_var_complete is None:
+        z_var = None
+    elif None in z_var_complete:
+        print("Not enough data entered for plotting a colour scale (z_var). Make sure that z_var, "
+              "z_var_unit, z_var_data, z_var_time_data and z_var_gps_time_data have all been completed. If z_var or"
+              " z_var_unit are not available, enter an empty string.")
+        z_var = None
     else:
-        colour_data = colour_data_uncut
+        pass
+    # Interpolates the data for the colour series over the data's time scale
+    if z_var is not None:
+        z_var_interp = interp.interp1d(z_var_time_data, z_var_data)
 
-    # Creates lists of points of latitude and longitude of colour values above and below the limits specified limits
-    # and notes the points
-    low_colour_lat_values = []
-    low_colour_long_values = []
+        # Creates the data series of same length as the latitude/longitude data:
+        colour_data_uncut = []
+        for point in [p for p in z_var_gps_time_data if min(z_var_time_data) <= p <= max(z_var_time_data)]:
+            colour_data_uncut.append(z_var_interp(point))
 
-    high_colour_lat_values = []
-    high_colour_long_values = []
+        # TODO: THIS NEEDS FIXING IN A WAY THAT WORKS BETTER. NEED TO MATCH THE TIME STAMPS OF THE LOCATION DATA WITH
+        #  THE COLOUR DATA.
+        # Makes sure that the colour data has the same length as the latitude and longitude data
+        colour_data = []
+        if len(geometry_data[0]) != len(colour_data_uncut):
+            for point in colour_data_uncut[:(len(geometry_data) - 1)]:
+                colour_data.append(point)
+        else:
+            colour_data = colour_data_uncut
 
-    try:
-        lower_limit = z_var_limits[0]
-        upper_limit = z_var_limits[1]
-    except IndexError:
-        print("Limits not entered in the correct format. Format should be [lower_limit, upper_limit] where lower_limit "
-              "and upper_limit are floats or integers.")
+        # Creates lists of points of latitude and longitude of colour values above and below the limits specified limits
+        # and notes the points
+        low_colour_lat_values = []
+        low_colour_long_values = []
+
+        high_colour_lat_values = []
+        high_colour_long_values = []
+
+        try:
+            lower_limit = z_var_limits[0]
+            upper_limit = z_var_limits[1]
+        except IndexError:
+            print("Limits not entered in the correct format. Format should be [lower_limit, upper_limit] where lower"
+                  "_limit and upper_limit are floats or integers.")
+            lower_limit = None
+            upper_limit = None
+
+        # Checks that the formats are correct for the lower_ and upper_limit(s)
+        if type(lower_limit) is str or type(lower_limit) is float:
+            print("Lower limit type not correct. Format should be [lower_limit, upper_limit] where lower_limit "
+                  "and upper_limit are floats or integers.")
+            lower_limit = None
+        if type(upper_limit) is str or type(upper_limit) is float:
+            print("Upper limit type not correct. Format should be [lower_limit, upper_limit] where lower_limit "
+                  "and upper_limit are floats or integers.")
+            upper_limit = None
+    else:
         lower_limit = None
         upper_limit = None
-
-    # Checks that the formats are correct for the lower_ and upper_limit(s)
-    if type(lower_limit) is str or type(lower_limit) is float:
-        print("Lower limit type not correct. Format should be [lower_limit, upper_limit] where lower_limit "
-              "and upper_limit are floats or integers.")
-        lower_limit = None
-    if type(upper_limit) is str or type(upper_limit) is float:
-        print("Upper limit type not correct. Format should be [lower_limit, upper_limit] where lower_limit "
-              "and upper_limit are floats or integers.")
-        upper_limit = None
+        colour_data = None
+        low_colour_lat_values = None
+        low_colour_long_values = None
+        high_colour_lat_values = None
+        high_colour_long_values = None
 
     # Adds geometry data
     # Highlights user defined outliers
@@ -998,9 +1036,12 @@ def backplt_map(lat, long, z_var, scale_factor=1, text_title=None, z_var_limits=
         plt.plot(geometry_data[0], geometry_data[1], 'r', zorder=1,
                  linewidth=0.5)
         # Plots the colour data over the base data
-        mapplot = plt.scatter(geometry_data[0], geometry_data[1],
-                              c=colour_data, marker='.',
-                              cmap='gnuplot', zorder=2)
+        if colour_data is not None:
+            mapplot = plt.scatter(geometry_data[0], geometry_data[1],
+                                  c=colour_data, marker='.',
+                                  cmap='gnuplot', zorder=2)
+        else:
+            mapplot = plt.scatter(geometry_data[0], geometry_data[1], marker='.', zorder=2)
         # Plots lower and upper limit data if limits are present.
         if lower_limit is not None:
             plt.scatter(low_colour_lat_values, low_colour_long_values,
@@ -1090,7 +1131,7 @@ def backplt_map(lat, long, z_var, scale_factor=1, text_title=None, z_var_limits=
     if text_title is not None:
         map_title = text_title
     elif scale_factor <= 5:
-        map_title += " v " + str(z_var[0][0][0])
+        map_title += " v " + str(z_var)
 
     # Splits title if its width exceeds 60
     wraped_title = textwrap.wrap(map_title, width=60)
@@ -1110,9 +1151,7 @@ def backplt_map(lat, long, z_var, scale_factor=1, text_title=None, z_var_limits=
         # Plots the colour map
         cbar = plt.colorbar(mapplot, cax=cax)
         # Adds a label to the colour bar
-        # z_var[0][0][0] = colour variable name
-        # z_var[0][0][1] = colour variable units
-        cbar.ax.set_ylabel(str(z_var[0][0][0]) + " (" + str(z_var[0][0][1]) + ")", rotation=90)
+        cbar.ax.set_ylabel(str(z_var) + " (" + str(z_var_unit) + ")", rotation=90)
 
     plt.show()
     return
@@ -1253,7 +1292,7 @@ def arm_data_formatting(arm_data, values_list, number_of_flights, flight_data_li
     arm_data_list = []
     if arm_data is True:
         for data_set in range(number_of_flights):
-            if len(arm_plot_data[1]) != 0:
+            if len(arm_plot_data[data_set][1]) != 0:
                 arm_data_list.append(True)
             else:
                 # Sets arm_data to false.
@@ -1330,12 +1369,12 @@ def select_plot_data_single(values_list, plot_information, number_of_flights):
             # matches the 'data sources' in the list structure values_list.
             for values_list_data in values_list[data_set]:
                 # Finds data source.
-                if data[2] == values_list_data[0].lower():
+                if data[2].lower() == values_list_data[0].lower():
                     data.append(values_list_index)
                     # Goes through each column searching for a match.
                     for column in values_list[data_set][values_list_index][1:]:
                         # Checks to see if they have the same title.
-                        if column[0].lower() == data[1]:
+                        if column[0].lower() == data[1].lower():
                             # if they do then the data is appended.
                             plot_data_temp.append([data[0], column, data[2]])
                             # exits for loop if data has been appended.
@@ -1356,6 +1395,8 @@ def manual_time_offset(values_list, time_x_offset, number_of_flights):
     elif len(time_x_offset) != number_of_flights:
         print("time_x_offset is not the same length as the number of flights. It has not been applied.")
         return values_list
+    else:
+        pass
 
     # Adds the offset to the time data on the x axis
     for flight in range(number_of_flights):
