@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Unit tests for the metar_processing.py and the log_to_xlsx.py
-codes.
-No tests are currently written for the GUI.
+Unit tests for the metar_processing.py code.
 
 @author Adrian Weishaeupl (aw6g15@soton.ac.uk)
 """
@@ -12,7 +10,9 @@ import os
 import json
 from autoflpy.util import metar_processing
 from shutil import copyfile
+from datetime import datetime
 from autoflpy.util.testing.check_str_in_content import *
+from autoflpy.util.text_manipulation import contents_opener
 
 
 class TestMetarProcessing(unittest.TestCase):
@@ -28,6 +28,14 @@ class TestMetarProcessing(unittest.TestCase):
         self.template_file_path = self.base_path
         self.template_file_name = self.data["flight_log_generator_input"]["template_file_name"]
 
+        copyfile(self.base_path + "test_generated_flight_logtest_metar.ipynb",
+                 self.base_path + "metar_testing.ipynb")
+
+    def tearDown(self):
+        if os.path.exists(self.base_path + "metar_testing.ipynb"):
+            os.remove(self.base_path + "metar_testing.ipynb")
+        pass
+
     def test_METAR_finder(self):
         # Checks if the METAR data exists. If it doesn't, it gets it from the
         # API. NOTE: API has a limit and so the original METAR file is not
@@ -73,17 +81,15 @@ class TestMetarProcessing(unittest.TestCase):
                                                          content)
         self.assertEqual(1, metar_information_present)
         # Runs no_METAR_returner code
-        content = metar_processing.no_metar_returner(['EGHE'], ['2019'], ['01'], ['23'],
-                                                     ['01'], ['23'], ['9'], ['10'],
+        content = metar_processing.no_metar_returner(['EGHE'], [20190123], [20190123], ['9'], ['10'],
                                                      content, 1, replace_key="META"
                                                      "R_INFORMATION")
         # Assigns expected content
-        expected_content = 'No METARs for EGHE for the date 23012019 to the date 23012019 from a '\
-            'starting time of 9:00 and an end time of 9:59.'
+        expected_content = 'No METARs for EGHE for the date 23/01/2019 to the date 23/01/2019 from a starting time of' \
+                           ' 9:00 and an end time of 9:59.'
         # Checks that the expected content is present in the content
         information_present = check_str_in_content(expected_content,
                                                    content)
-        print(content)
         self.assertEqual(1, information_present)
 
     def test_METAR_quota_returner(self):
@@ -139,6 +145,36 @@ class TestMetarProcessing(unittest.TestCase):
         if os.path.exists(generated_file_name):
             os.remove(generated_file_name)
 
+    def test_metar_replacer(self):
+        """Tests the metar_replacer()
+        TODO: This test needs to be more thorough
+        """
+        file_path = self.base_path
+        file_name = "metar_testing.ipynb"
+        location = "EGHE_20190123_20190123_9_9"
+        year = "2019"
+        month = "01"
+        day = "23"
+        month_end = "01"
+        day_end = "23"
+        start_time_hours = "9"
+        end_time_hours = "10"
+        flight = 0
+        metar_file_path = self.base_path
+
+        metar_processing.metar_replacer(file_path, file_name, location, year, month, day,
+                                        month_end, day_end, start_time_hours, end_time_hours, flight,
+                                        metar_file_path)
+
+        # Checks that the file was recently created.
+        filetime = os.stat(file_path + file_name)
+        # Finds the time since the file has been created.
+        time_diff = datetime.now() - datetime.fromtimestamp(filetime.st_mtime)
+        # Checks that the time difference is less than 0.7 seconds.
+        self.assertLess(time_diff.microseconds, 7e5)
+        # Check that the files weren't created in the past.
+        self.assertGreaterEqual(time_diff.microseconds, 0)
+
 
 if __name__ == '__main__':
     unittest.main()
